@@ -3,9 +3,9 @@ import sys
 from pytest_docker_tools.builder import fixture_factory
 
 
-@fixture_factory(scope='session')
+@fixture_factory(scope="session")
 def fetch(request, docker_client, wrapper_class, **kwargs):
-    ''' Docker image: Fetched from {repository} '''
+    """ Docker image: Fetched from {repository} """
 
     sys.stdout.write(f'Fetching {kwargs["repository"]}\n')
 
